<?php

/*
Copyright (C) 2009-2013, Rémi Jean (zwiicms@outlook.com)
<http://zwiicms.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General License for more details.

You should have received a copy of the GNU General License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

class backups extends zwii
{
	var $icons_path,
		$backups_path;

	/*
		Système
	*/

	function __construct()
	{
		parent::__construct();
		$this->title = $this->t('Sauvegardes');
		$this->icons_path = 'zwii/plugins/backups/extras/icons/';
		$this->backups_path = 'zwii/data/backups/';
		if(!is_dir($this->backups_path))
		{
			mkdir($this->backups_path);
		}
	}

	function builder()
	{
		$in = !empty($this->url[1]) ? $this->url[1] : 'home';
		switch($in)
		{
			case 'home' :
				return $this->home();
				break;

			case 'delete' :
				return $this->delete();
				break;

			default :
				return $this->error;
		}
	}

	/*
		Plugins
	*/

	function home()
	{
		if(isset($_POST['submit']))
		{
			$this->download();
			return $this->redirect('/backups');
		}
		else
		{
			return '<h2>' . $this->title . '</h2>'
				. '<form name="form" method="post">'
				. '<p>'
				. '<input type="submit" name="submit" value="' . $this->t('Sauvegarder') . '">'
				. '</p>'
				. '</form>'
				. '<table>'
				. '<tr><th>' . $this->t('Date') . '</th><th>' . $this->t('Actions') . '</th></tr>'
				. $this->backups_list()
				. '</table>';
		}
	}

	function delete()
	{
		if(!isset($this->url[2])
		|| !file_exists($this->backups_path . $this->url[2]))
		{
			return $this->error;
		}
		else
		{
			if(false !== unlink($this->backups_path . $this->url[2]))
			{
				$_SESSION['POPUP'] = $this->t('Sauvegarde supprimée avec succès !');
			}
			else
			{
				$_SESSION['POPUP'] = $this->t('Impossible de supprimer la sauvegarde !');
			}
			return $this->redirect('/backups');
		}
	}

	/*
		Fonctions
	*/

	function download()
	{
		$zip = new ZipArchive();
		if($zip->open($this->backups_path . time() . '.zip', ZipArchive::CREATE) === true)
		{
			$zip->addEmptyDir('data');
			$zip->addEmptyDir('data/pages');
			$zip->addFromString('data/settings.ini', file_get_contents($this->settings_path));
			$zip->addFromString('data/system.ini', file_get_contents($this->system_path));
			$handle = opendir($this->pages_path);
			while(false !== ($entry = readdir($handle)))
			{
				if(is_file($this->pages_path . $entry))
				{
					$zip->addFromString('data/pages/' . $entry, file_get_contents($this->settings_path));
				}
			}
			$zip->close();
			return $_SESSION['POPUP'] = $this->t('Sauvegarde effectuée avec succès !');
		}
		else
		{
			return $_SESSION['POPUP'] = $this->t('Impossible de sauvegarder les données !');
		}
	}

	function backups_list()
	{
		$entries = array();
		$handle = opendir($this->backups_path);
		while(false !== ($entry = readdir($handle)))
		{
			if(is_file($this->backups_path . $entry))
			{
				$date = date($this->t('d/m/Y - H:i:s'), basename($entry, '.zip'));
				$entries[$entry] = $date;
			}
		}
		closedir($handle);
		asort($entries, SORT_NUMERIC);
		foreach($entries as $key => $value)
		{
			@$backups .= '<tr>'
					. '<td>' . $value . '</td>'
					. '<td>'
					. '<a href="' . $this->backups_path . $key . '"><img src="' . $this->icons_path . 'download.png" title="' . $this->t('Télécharger') . '" alt="' . $this->t('Télécharger') . '"></a> '
					. '<a href="?/backups/delete/' . $key . '" onClick=\'return confirm("' . $this->t('Êtes-vous certain de vouloir supprimer cette sauvegarde ?') . '")\'><img src="' . $this->icons_path . 'delete.png" title="' . $this->t('Supprimer') . '" alt="' . $this->t('Supprimer') . '"></a>'
					. '</td>'
					. '</tr>';
		}
		return (isset($backups)) ? $backups : '<tr><td colspan="2">' . $this->t('Aucune sauvegarde.') . '</td></tr>';
	}
}

?>